# Support Vector Spectrum Approximator

The Support Vector Spectrum Approximator (SVSA) is a python package for creating quick and accurate approximations of any spectral lineshapes model.

The python package is available on pypi.

A basic vignette of how to use SVSA to approximate the Tenti S6 lineshape model is available in as an ipython notebook. Once fit in python you can export the fit for use in any other language. Examples can be found for how to do this for Matlab and R.
